
from fastapi import FastAPI, HTTPException, Header
from fastapi.middleware.cors import CORSMiddleware
from pydantic import BaseModel, Field, model_validator
import argparse
import uvicorn
from .log import Log

default=8008

app = FastAPI(
    title="LLM Service",
    description="Provides an OpenAI-compatible API for custom large language models.",
    version="1.0.1",
)

# --- Configure CORS ---
origins = [
    "*", # Allows all origins (convenient for development, insecure for production)
    # Add the specific origin of your "别的调度" tool/frontend if known
    # e.g., "http://localhost:5173" for a typical Vite frontend dev server
    # e.g., "http://127.0.0.1:5173"
]

app.add_middleware(
    CORSMiddleware,
    allow_origins=origins,  # Specifies the allowed origins
    allow_credentials=True, # Allows cookies/authorization headers
    allow_methods=["*"],    # Allows all methods (GET, POST, OPTIONS, etc.)
    allow_headers=["*"],    # Allows all headers (Content-Type, Authorization, etc.)
)
# --- End CORS Configuration ---


@app.get("/")
async def root():
    """ x """
    return {"message": "LLM Service is running."}


if __name__ == "__main__":
    
    parser = argparse.ArgumentParser(
        description="Start a simple HTTP server similar to http.server."
    )
    parser.add_argument(
        'port',
        metavar='PORT',
        type=int,
        nargs='?', # 端口是可选的
        default=default,
        help=f'Specify alternate port [default: {default}]'
    )
    # 创建一个互斥组用于环境选择
    group = parser.add_mutually_exclusive_group()

    # 添加 --dev 选项
    group.add_argument(
        '--dev',
        action='store_true', # 当存在 --dev 时，该值为 True
        help='Run in development mode (default).'
    )

    # 添加 --prod 选项
    group.add_argument(
        '--prod',
        action='store_true', # 当存在 --prod 时，该值为 True
        help='Run in production mode.'
    )
    args = parser.parse_args()

    if args.prod:
        env = "prod"
    else:
        # 如果 --prod 不存在，默认就是 dev
        env = "dev"

    port = args.port
    if env == "dev":
        port += 100
        Log.reset_level('debug',env = env)
        reload = True
        app_import_string = f"{__package__}.server:app" # <--- 关键修改：传递导入字符串
    elif env == "prod":
        Log.reset_level('info',env = env)# ['debug', 'info', 'warning', 'error', 'critical']
        reload = False
        app_import_string = app
    else:
        reload = False
        app_import_string = app
    

    # 使用 uvicorn.run() 来启动服务器
    # 参数对应于命令行选项
    uvicorn.run(
        app_import_string,
        host="0.0.0.0",
        port=port,
        reload=reload  # 启用热重载
    )



import logging
import os
from logging.handlers import RotatingFileHandler, TimedRotatingFileHandler

class Logger:
    """log

    Returns:
        _type_: single
    """
    _instance = None

    def __new__(cls, *args, **kwargs):
        if cls._instance is None:
            cls._instance = super().__new__(cls)
        return cls._instance

    def __init__(self,level = 'debug',log_file_name = "app.log"):
        """
        Level (级别): 定义日志的严重程度。从低到高依次是：
        DEBUG: 详细的调试信息，通常只在开发阶段使用。
        INFO: 确认程序按预期运行。
        WARNING: 发生了意外，或将来可能出现问题，但程序仍在正常运行。
        ERROR: 发生了严重错误，程序可能无法执行某些功能。
        CRITICAL: 发生了严重错误，程序可能无法继续运行。
                # --- 1. 定义日志级别 ---
        # 建议在开发环境使用 DEBUG，生产环境使用 INFO 或 WARNING

        """
        if not hasattr(self, 'initialized'):
            self.initialized = True

            if level == 'debug':
                self.LOG_LEVEL = logging.DEBUG  # 开发阶段
            elif level == 'info':
                self.LOG_LEVEL = logging.INFO  # 生产阶段
            elif level == 'warning':
                self.LOG_LEVEL = logging.WARNING
            elif level == 'error':
                self.LOG_LEVEL = logging.ERROR
            elif level == 'critical':
                self.LOG_LEVEL = logging.CRITICAL
            else:
                self.LOG_LEVEL = logging.INFO  # 默认级别

            # --- 2. 定义日志文件路径和名称 ---
            self.LOG_DIR = "logs"
            self.LOG_FILE_NAME = log_file_name
            self.LOG_FILE_PATH = os.path.join(self.LOG_DIR, self.LOG_FILE_NAME)

            # 确保日志目录存在
            os.makedirs(self.LOG_DIR, exist_ok=True)
            self.logger = None
            self.setup_logging()
            self.env = 'dev'

    def reset_level(self,level = 'debug',env = 'dev'):
        if level == 'debug':
            self.LOG_LEVEL = logging.DEBUG  # 开发阶段
        elif level == 'info':
            self.LOG_LEVEL = logging.INFO  # 生产阶段
        elif level == 'warning':
            self.LOG_LEVEL = logging.WARNING
        elif level == 'error':
            self.LOG_LEVEL = logging.ERROR
        elif level == 'critical':
            self.LOG_LEVEL = logging.CRITICAL
        else:
            self.LOG_LEVEL = logging.INFO  # 默认级别

        self.setup_logging()
        self.env = env

    def setup_logging(self):
        """# --- 3. 配置 Logger ---
        """
        # 获取根 Logger (也可以创建自定义的 Logger: logging.getLogger('my_app'))
        logger = logging.getLogger()
        logger.setLevel(self.LOG_LEVEL)

        # 避免重复添加 Handler (如果多次调用 setup_logging)
        if not logger.handlers:
            # --- 4. 配置 Formatter (格式化器) ---
            # 常见格式：时间 - 日志级别 - Logger名称 - 模块名 - 行号 - 消息
            formatter = logging.Formatter(
                '%(asctime)s - %(levelname)s - %(name)s - %(module)s:%(lineno)d - %(message)s'
            )

            # --- 5. 配置 Handler (处理器) ---

            # 5.1 控制台处理器 (StreamHandler)
            console_handler = logging.StreamHandler()
            console_handler.setLevel(logging.INFO) # 控制台只显示 INFO 及以上级别的日志
            console_handler.setFormatter(formatter)
            logger.addHandler(console_handler)

            # 5.2 文件处理器 (RotatingFileHandler 或 TimedRotatingFileHandler)

            file_handler = RotatingFileHandler(
                self.LOG_FILE_PATH,
                maxBytes=10 * 1024 * 1024, # 10 MB
                backupCount=5,
                encoding='utf-8'
            )
            file_handler.setLevel(self.LOG_LEVEL) # 文件中显示所有指定级别的日志
            file_handler.setFormatter(formatter)
            logger.addHandler(file_handler)

        self.logger = logger


Log = Logger(log_file_name = "app.log")
del Logger

"""
from .log import Log
logger = Log.logger
"""
